@@ -192,7 +192,7 @@ def timeseries_to_seas_trace(seas, text, dash=None, showlegend=True, visible_lin
         trace = go.Scatter(x=seas.index,
                            y=seas[col],
                            hoverinfo='y',
-                           name=col,
+                           name=str(col),
                            hovertemplate=hovertemplate_default,
                            text=text,
                            visible=line_visible(col, visible_line_years),
@@ -221,7 +221,7 @@ def timeseries_to_reindex_year_trace(dft, text, dash=None, current_select_year=N
         trace = go.Scatter(x=dft.index,
                            y=dft[col],
                            hoverinfo='y',
-                           name=col,
+                           name=str(col),
                            hovertemplate=hovertemplate_default,
                            text=text,
                            visible=line_visible(colyear),
